[ros-dev] [ros-diffs] 01/01: [WLNOTIFY] Add sens service stubs

Ged Murphy gedmurphy.maillists at gmail.com
Wed Aug 8 08:28:35 UTC 2018


Hi Eric,

Do you plan on implementing sysntfy which sens is dependent upon from win7, or do you plan to stick with the XP way via winlogon?
If so, I have some undocumented notes and code on sysntfy which might be of some use.

Ged.

-----Original Message-----
From: Ros-diffs <ros-diffs-bounces at reactos.org> On Behalf Of Eric Kohl
Sent: Tuesday, 07 August 2018 21:57
To: ros-diffs at reactos.org
Subject: [ros-diffs] 01/01: [WLNOTIFY] Add sens service stubs

https://git.reactos.org/?p=reactos.git;a=commitdiff;h=fb5d5ecd64e1e47701e922e08fd97b29a1d418be

commit fb5d5ecd64e1e47701e922e08fd97b29a1d418be
Author:     Eric Kohl <eric.kohl at reactos.org>
AuthorDate: Tue Aug 7 22:56:33 2018 +0200
Commit:     Eric Kohl <eric.kohl at reactos.org>
CommitDate: Tue Aug 7 22:56:33 2018 +0200

    [WLNOTIFY] Add sens service stubs
---
 dll/win32/wlnotify/CMakeLists.txt        |  1 +
 dll/win32/wlnotify/{test.c => senssvc.c} | 56 +++++++++++++++++---------------
 dll/win32/wlnotify/test.c                |  2 +-
 dll/win32/wlnotify/wlnotify.spec         | 24 +++++++-------
 4 files changed, 43 insertions(+), 40 deletions(-)

diff --git a/dll/win32/wlnotify/CMakeLists.txt b/dll/win32/wlnotify/CMakeLists.txt
index 1db47fffe2..6cbf00ce86 100644
--- a/dll/win32/wlnotify/CMakeLists.txt
+++ b/dll/win32/wlnotify/CMakeLists.txt
@@ -3,6 +3,7 @@ spec2def(wlnotify.dll wlnotify.spec ADD_IMPORTLIB)
 
 list(APPEND SOURCE
     schedsvc.c
+    senssvc.c
     test.c
     wlnotify.c
     precomp.h)
--- a/dll/win32/wlnotify/test.c
+++ b/dll/win32/wlnotify/test.c
@@ -170,7 +170,7 @@ WINAPI
 TestPostShellEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestStartShellEvent\n");
+    DPRINT("TestPostShellEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); diff --git a/dll/win32/wlnotify/wlnotify.spec b/dll/win32/wlnotify/wlnotify.spec
index 737448d4d9..2eb0b647c1 100644
--- a/dll/win32/wlnotify/wlnotify.spec
+++ b/dll/win32/wlnotify/wlnotify.spec
@@ -5,18 +5,18 @@
 ;@ stub SCardSuspendCertProp
 @ stdcall SchedEventLogoff(ptr)
 @ stdcall SchedStartShell(ptr)
-;@ stub SensDisconnectEvent
-;@ stub SensLockEvent
-;@ stub SensLogoffEvent
-;@ stub SensLogonEvent
-;@ stub SensPostShellEvent
-;@ stub SensReconnectEvent
-;@ stub SensShutdownEvent
-;@ stub SensStartScreenSaverEvent
-;@ stub SensStartShellEvent
-;@ stub SensStartupEvent
-;@ stub SensStopScreenSaverEvent
-;@ stub SensUnlockEvent
+@ stdcall SensDisconnectEvent(ptr)
+@ stdcall SensLockEvent(ptr)
+@ stdcall SensLogoffEvent(ptr)
+@ stdcall SensLogonEvent(ptr)
+@ stdcall SensPostShellEvent(ptr)
+@ stdcall SensReconnectEvent(ptr)
+@ stdcall SensShutdownEvent(ptr)
+@ stdcall SensStartScreenSaverEvent(ptr) @ stdcall 
+SensStartShellEvent(ptr) @ stdcall SensStartupEvent(ptr) @ stdcall 
+SensStopScreenSaverEvent(ptr) @ stdcall SensUnlockEvent(ptr)
 ;@ stub ShowNotificationBallonW
 @ stdcall TestDisconnectEvent(ptr)
 @ stdcall TestLockEvent(ptr)





More information about the Ros-dev mailing list
diff --git a/dll/win32/wlnotify/test.c b/dll/win32/wlnotify/senssvc.c similarity index 86% copy from dll/win32/wlnotify/test.c copy to dll/win32/wlnotify/senssvc.c index e3911d3b75..e238a849a9 100644
--- a/dll/win32/wlnotify/test.c
+++ b/dll/win32/wlnotify/senssvc.c
@@ -1,12 +1,13 @@
 /*
  * PROJECT:     ReactOS system libraries
  * LICENSE:     GPL - See COPYING in the top level directory
  * FILE:        dll/win32/wlnotify/test.c
  * PURPOSE:     Winlogon notifications
  * PROGRAMMER:  Eric Kohl
  */
 
 #include "precomp.h"
+#include <winsvc.h>
 
 #define _NDEBUG
 #include <debug.h>
@@ -14,10 +15,10 @@
 
 VOID
 WINAPI
-TestLogonEvent(
+SensDisconnectEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestLogonEvent\n");
+    DPRINT("SensDisconnectEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -31,10 +32,10 @@ TestLogonEvent(
 
 VOID
 WINAPI
-TestLogoffEvent(
+SensLockEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestLogoffEvent\n");
+    DPRINT("SensLockEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -48,10 +49,10 @@ TestLogoffEvent(
 
 VOID
 WINAPI
-TestLockEvent(
+SensLogoffEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestLockEvent\n");
+    DPRINT("SensLogoffEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -65,10 +66,10 @@ TestLockEvent(
 
 VOID
 WINAPI
-TestUnlockEvent(
+SensLogonEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestUnlockEvent\n");
+    DPRINT("SensLogonEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -82,10 +83,10 @@ TestUnlockEvent(
 
 VOID
 WINAPI
-TestStartupEvent(
+SensPostShellEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestStartupEvent\n");
+    DPRINT("SensPostShellEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -99,10 +100,10 @@ TestStartupEvent(
 
 VOID
 WINAPI
-TestShutdownEvent(
+SensReconnectEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestShutdownEvent\n");
+    DPRINT("SensReconnectEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -116,10 +117,10 @@ TestShutdownEvent(
 
 VOID
 WINAPI
-TestStartScreenSaverEvent(
+SensShutdownEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestStartScreenSaverEvent\n");
+    DPRINT("SensShutdownEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -133,10 +134,10 @@ TestStartScreenSaverEvent(
 
 VOID
 WINAPI
-TestStopScreenSaverEvent(
+SensStartScreenSaverEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestStopScreenSaverEvent\n");
+    DPRINT("SensStartScreenSaverEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -150,10 +151,10 @@ TestStopScreenSaverEvent(
 
 VOID
 WINAPI
-TestStartShellEvent(
+SensStartShellEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestStartShellEvent\n");
+    DPRINT("SensStartShellEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -167,10 +168,10 @@ TestStartShellEvent(
 
 VOID
 WINAPI
-TestPostShellEvent(
+SensStartupEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestStartShellEvent\n");
+    DPRINT("SensStartupEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -181,12 +182,13 @@ TestPostShellEvent(
     DPRINT("pStatusCallback: %p\n", pInfo->pStatusCallback);  }
 
+
 VOID
 WINAPI
-TestDisconnectEvent(
+SensStopScreenSaverEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestDisconnectEvent\n");
+    DPRINT("SensStopScreenSaverEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); @@ -200,10 +202,10 @@ TestDisconnectEvent(
 
 VOID
 WINAPI
-TestReconnectEvent(
+SensUnlockEvent(
     PWLX_NOTIFICATION_INFO pInfo)
 {
-    DPRINT("TestReconnectEvent\n");
+    DPRINT("SensUnlockEvent\n");
     DPRINT("Size: %lu\n", pInfo->Size);
     DPRINT("Flags: %lx\n", pInfo->Flags);
     DPRINT("UserName: %S\n", pInfo->UserName); diff --git a/dll/win32/wlnotify/test.c b/dll/win32/wlnotify/test.c index e3911d3b75..8f8705547a 100644
@@ -1,12 +1,13 @@
  * PROJECT:     ReactOS system libraries
  * LICENSE:     GPL - See COPYING in the top level directory
- * FILE:        dll/win32/wlnotify/test.c
- * PURPOSE:     Winlogon notifications
- * PROGRAMMER:  Eric Kohl
+ * FILE:        dll/win32/wlnotify/senssvc.c
+ * PURPOSE:     SENS service logon notifications
+ * PROGRAMMER:  Eric Kohl <eric.kohl at reactos.org>
  */
 